==> jc-1.4.0.tar.gz: java/io/IOException.h <==
// public class java.io.IOException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_io_IOException_H_
#define _JC_java_io_IOException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_IOException$sub_refs	_jc_java_io_IOException$sub_refs;
typedef struct _jc_java_io_IOException$sub_nonrefs	_jc_java_io_IOException$sub_nonrefs;
typedef struct _jc_java_io_IOException$refs	_jc_java_io_IOException$refs;
typedef struct _jc_java_io_IOException$nonrefs	_jc_java_io_IOException$nonrefs;
typedef struct _jc_java_io_IOException$object	_jc_java_io_IOException$object;

typedef struct _jc_java_io_IOException$fields_struct	_jc_java_io_IOException$fields_struct;
typedef const struct _jc_java_io_IOException$vmethods	_jc_java_io_IOException$vmethods;
typedef const struct _jc_java_io_IOException$vtable	_jc_java_io_IOException$vtable;
typedef const struct _jc_java_io_IOException$vtype	_jc_java_io_IOException$vtype;

// Class fields structure
struct _jc_java_io_IOException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_IOException$fields_struct _jc_java_io_IOException$class_fields;

// Constructors
extern void _jc_java_io_IOException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_IOException$object *);
extern void _jc_java_io_IOException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_IOException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_io_IOException$vmethods {
};

// Vtable
struct _jc_java_io_IOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
};

// Vtype
struct _jc_java_io_IOException$vtype {
	_jc_type			type;
	_jc_java_io_IOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_IOException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_IOException$refs {
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_IOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_IOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
};

// Object instance structure
struct _jc_java_io_IOException$object {
	_jc_java_io_IOException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_IOException$vtype	*vtype;
	_jc_java_io_IOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_IOException$vtype _jc_java_io_IOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_IOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_IOException$class_object;

#endif	/* _JC_java_io_IOException_H_ */

==> jc-1.4.6.tar.gz: java/io/IOException.h <==
// public class java.io.IOException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_io_IOException_H_
#define _JC_java_io_IOException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_IOException$sub_refs	_jc_java_io_IOException$sub_refs;
typedef struct _jc_java_io_IOException$sub_nonrefs	_jc_java_io_IOException$sub_nonrefs;
typedef struct _jc_java_io_IOException$refs	_jc_java_io_IOException$refs;
typedef struct _jc_java_io_IOException$nonrefs	_jc_java_io_IOException$nonrefs;
typedef struct _jc_java_io_IOException$object	_jc_java_io_IOException$object;

typedef struct _jc_java_io_IOException$fields_struct	_jc_java_io_IOException$fields_struct;
typedef const struct _jc_java_io_IOException$vmethods	_jc_java_io_IOException$vmethods;
typedef const struct _jc_java_io_IOException$vtable	_jc_java_io_IOException$vtable;
typedef const struct _jc_java_io_IOException$vtype	_jc_java_io_IOException$vtype;

// Class fields structure
struct _jc_java_io_IOException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_IOException$fields_struct _jc_java_io_IOException$class_fields;

// Constructors
extern void _jc_java_io_IOException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_IOException$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_IOException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_IOException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_IOException$vmethods {
};

// Vtable
struct _jc_java_io_IOException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
};

// Vtype
struct _jc_java_io_IOException$vtype {
	_jc_type			type;
	_jc_java_io_IOException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_IOException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_IOException$refs {
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_IOException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_IOException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
};

// Object instance structure
struct _jc_java_io_IOException$object {
	_jc_java_io_IOException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_IOException$vtype	*vtype;
	_jc_java_io_IOException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_IOException$vtype _jc_java_io_IOException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_IOException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_IOException$class_object;

#endif	/* _JC_java_io_IOException_H_ */
